/*
   Copyright (c) 2014 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

#ifndef CONTROL_H_
#define CONTROL_H_

#include "pil.h"

//global structure for control variables
struct CONTROL_VARS
{
   Uint16 Fs;
   Uint16 Fpwm;
   int16 Vmax;
   boolean ClosedFlag;

   //PIL Extension for probed variables
   PIL_OVERRIDE_PROBE(int16,Iset);

   int16 Ierr;
   int16 Vset;
   int16 MPosition;
   int16 MPos0Angle;
   int16 Iuvw[3];
   int16 Iuvw_scaled[3];
   int32 Iuvw32[3];
   int32 Iuvw32_scaled[3];
   float IuvwFloat[3];
   float IuvwFloat_scaled[3];
   int16 MSpeed;
   int16 MPos0;
   int16 MPos0Last;
   int16 MPosAccumulated;
   int16 MPosAccuCtr;
   Uint16 CmtnPointer;      // Input: Commutation (or switching) state pointer input (Q0) ;
   int16 DutyFunc;   	    // Input: PWM period modulation input (Q15)
   Uint16 PosInc;
   Uint32 PosCtr;
   Uint16 Pos;
};

extern struct CONTROL_VARS ControlVars;

//global structure for analog inputs
struct ANALOG_INPUTS
{
   Int16 Iu;
   Int16 Iv;
   Int16 Iw;

   //PIL Extension for probed variables
   PIL_OVERRIDE_PROBE(Int16,Idc);

   Int16 Vu;
   Int16 Vv;
   Int16 Vw;
   Int16 Trim;

   Uint32 IuAccu;
   Uint32 IvAccu;
   Uint32 IwAccu;
   Uint32 IdcAccu;

   Uint16 IuOffset;
   Uint16 IvOffset;
   Uint16 IwOffset;
   Uint16 IdcOffset;

   Uint16 AccuCtr;
};

extern struct ANALOG_INPUTS AIn;

extern boolean readInputs(void);
extern void initControl(void);
extern void stopControl(void);
extern void startControl(void);
extern void resetControl(void);
extern void controlStep(void);

#endif /*CONTROL_H_*/
