/*
   Copyright (c) 2014 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

/**
 * @file pi.h
 * @brief Basic PI-Regulator with anti-windup.
 */

#ifndef PI_H_
#define PI_H_

#include "plx_types.h"

#ifdef __cplusplus
extern "C" {
#endif

// fixed-point references
#define PLX_PI_Q_KP 10
#define PLX_PI_R_KP 1024
#define PLX_PI_Q_KI 14
#define PLX_PI_R_KI 16384

typedef struct PLX_PI_OBJ
{
	int16_t data[8];
} PLX_PI_Obj_t;

typedef struct PLX_PI_Obj_t *PLX_PI_Handle_t;

extern PLX_PI_Handle_t PLX_PI_init(void *aMemory, const size_t aNumBytes);

extern void PLX_PI_configure(PLX_PI_Handle_t aPiHandle, int16_t aKp, int16_t aKi);

extern void PLX_PI_reset(PLX_PI_Handle_t aPiHandle);

extern void PLX_PI_calculateOutput(PLX_PI_Handle_t aPiHandle, int16_t aError, int16_t *aOut);

extern void PLX_PI_updateIntegrator(PLX_PI_Handle_t aPiHandle, int16_t aOutLimited);

#ifdef __cplusplus
}
#endif // extern "C"

#endif /* PI_H_ */
