% Input/Output Voltages
V_i = 400; % input voltage (DC)
V_o_max = 54; % maximum output voltage target (DC)
V_o_min = 48; % minimum output voltage target (DC)

% Transformer
N_p = 75; % number of turns on primary side windings
N_s = 25; % number of turns on secondary side windings

mu0 = 4*pi*1e-7; % magnetic constant/permeability of free space (H/m)
murunsat = 6500; % unsaturated relative permeability
mursat = 6; % saturated relative permeability
Bsat = 0.49; % flux density saturation

areaside = 360e-6*2; % cross-sectional area of core side legs (m^2)
areamid = 704e-6*2; % cross-sectional area of core middle leg (m^2)
% (2 cores are in parallel)

lengthcoreside = 57.2e-3; % length of flux path of side core leg (m)
lengthcoremid = 26e-3; % length of flux path of middle core leg (m)
lengthgap = 3e-3; % length of flux path of all leg air gaps (m)

Rm1 = 1/(mu0*murunsat)*lengthcoreside*2/(areaside) + 1/mu0*lengthgap/(areaside); % reluctance of side leg of the core
Rm2 = 1/(mu0*murunsat)*lengthcoremid*2/(areamid) + 1/mu0*lengthgap/(areamid); % reluctance of middle leg of the core
Rm3 = Rm1; % reluctance of side leg of the core

M = N_s^2*Rm2/(Rm1*Rm2 + Rm1*Rm3 + Rm2*Rm3);
L1 = N_s^2*(Rm2+Rm3)/(Rm1*Rm2 + Rm1*Rm3 + Rm2*Rm3) - M;
L2 = N_s^2*(Rm1+Rm2)/(Rm1*Rm2 + Rm1*Rm3 + Rm2*Rm3) - M;

Lm_delta = (L1*L2 + L1*M + L2*M)/M*(N_p/N_s)^2; % equivalent magnetization inductance at primary side
L1_delta = (L1*L2 + L1*M + L2*M)/L2; % equivalent output series inductance at secondary side
L2_delta = (L1*L2 + L1*M + L2*M)/L1; % equivalent output series inductance at secondary side

L_o = L1_delta; % used in model gain controller parameter

% Capacitor
C_o = 30e-6;

% Load
P_n = 5e3;
R_o = V_o_min^2/P_n*2; % half rated power

% Modulator
f_sw = 20e3; % switching frequency

% Transformer winding resistance taking skin effect into account
h_p_copper = 0.1e-3;
h_p_total = 0.18e-3;
h_s_copper = 0.3e-3;
h_s_total = 0.38e-3;
sigma = 5.96e7;
v_p = h_p_copper*sqrt(pi*mu0*sigma*f_sw);
v_s = h_s_copper*sqrt(pi*mu0*sigma*f_sw);
k_skin_p = v_p*(sinh(2*v_p) + sin(2*v_p))/(cosh(2*v_p)-cos(2*v_p));
k_skin_s = v_s*(sinh(2*v_s) + sin(2*v_s))/(cosh(2*v_s)-cos(2*v_s));
l_p = ((22+32*2)*1e-3*2*2+ 2*h_p_total*4*(N_p-1))*N_p/2;
s_p = 36.5e-3*h_p_copper;
l_s = (((22+32*2)*1e-3*2 + 2*h_p_total*4*N_p)*2 + 2*h_s_total*4*(N_s-1))*N_s/2;
s_s = 36.5e-3*h_s_copper;
R_p = 1.68e-8*l_p/s_p*k_skin_p; % primary side equivalent resistance
R_s = 1.68e-8*l_s/s_s*k_skin_s; % secondary side equivalent resistance

% Series inductance of the transformer
L_r = 3e-6;